==> jc-1.4.0.tar.gz: javax/print/attribute/standard/SheetCollate.h <==
// public final class javax.print.attribute.standard.SheetCollate

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 96da48e7223778b9 javax_print_attribute_EnumSyntax
// @dep_class 9637c6b3a25d0ae javax_print_attribute_standard_SheetCollate

// header file dependencies
// @dep_header javax_print_attribute_EnumSyntax

#include "javax/print/attribute/EnumSyntax.h"

#ifndef _JC_javax_print_attribute_standard_SheetCollate_H_
#define _JC_javax_print_attribute_standard_SheetCollate_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_print_attribute_standard_SheetCollate$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_SheetCollate$sub_refs	_jc_javax_print_attribute_standard_SheetCollate$sub_refs;
typedef struct _jc_javax_print_attribute_standard_SheetCollate$sub_nonrefs	_jc_javax_print_attribute_standard_SheetCollate$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_SheetCollate$refs	_jc_javax_print_attribute_standard_SheetCollate$refs;
typedef struct _jc_javax_print_attribute_standard_SheetCollate$nonrefs	_jc_javax_print_attribute_standard_SheetCollate$nonrefs;
typedef struct _jc_javax_print_attribute_standard_SheetCollate$object	_jc_javax_print_attribute_standard_SheetCollate$object;

typedef struct _jc_javax_print_attribute_standard_SheetCollate$fields_struct	_jc_javax_print_attribute_standard_SheetCollate$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_SheetCollate$vmethods	_jc_javax_print_attribute_standard_SheetCollate$vmethods;
typedef const struct _jc_javax_print_attribute_standard_SheetCollate$vtable	_jc_javax_print_attribute_standard_SheetCollate$vtable;
typedef const struct _jc_javax_print_attribute_standard_SheetCollate$vtype	_jc_javax_print_attribute_standard_SheetCollate$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_SheetCollate$fields_struct {
	struct _jc_javax_print_attribute_standard_SheetCollate$object	*COLLATED;
	struct _jc_javax_print_attribute_standard_SheetCollate$object	*UNCOLLATED;
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24SheetCollate;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_SheetCollate$fields_struct _jc_javax_print_attribute_standard_SheetCollate$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_SheetCollate$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_print_attribute_standard_SheetCollate$object *, jint);

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_SheetCollate$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_SheetCollate$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_SheetCollate$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_SheetCollate$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_SheetCollate$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_SheetCollate$method_info$getName$bec186f2ce7e1882;

// Static methods
extern void _jc_javax_print_attribute_standard_SheetCollate$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_SheetCollate$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_print_attribute_standard_SheetCollate$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_SheetCollate$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_SheetCollate$object *);
};

// Vtable
struct _jc_javax_print_attribute_standard_SheetCollate$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_EnumSyntax$vmethods	javax_print_attribute_EnumSyntax;
	_jc_javax_print_attribute_standard_SheetCollate$vmethods	javax_print_attribute_standard_SheetCollate;
};

// Vtype
struct _jc_javax_print_attribute_standard_SheetCollate$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_SheetCollate$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_SheetCollate$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_SheetCollate$refs {
    _jc_javax_print_attribute_standard_SheetCollate$sub_refs	javax_print_attribute_standard_SheetCollate;
    _jc_javax_print_attribute_EnumSyntax$sub_refs	javax_print_attribute_EnumSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_SheetCollate$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_SheetCollate$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_EnumSyntax$sub_nonrefs	javax_print_attribute_EnumSyntax;
    _jc_javax_print_attribute_standard_SheetCollate$sub_nonrefs	javax_print_attribute_standard_SheetCollate;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_SheetCollate$object {
	_jc_javax_print_attribute_standard_SheetCollate$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_SheetCollate$vtype	*vtype;
	_jc_javax_print_attribute_standard_SheetCollate$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_SheetCollate$vtype _jc_javax_print_attribute_standard_SheetCollate$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_SheetCollate, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_SheetCollate$class_object;

#endif	/* _JC_javax_print_attribute_standard_SheetCollate_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/standard/SheetCollate.h <==
// public final class javax.print.attribute.standard.SheetCollate

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 96da48e7223778b9 javax_print_attribute_EnumSyntax
// @dep_class 9637c6b3a25d0ae javax_print_attribute_standard_SheetCollate

// header file dependencies
// @dep_header javax_print_attribute_EnumSyntax

#include "javax/print/attribute/EnumSyntax.h"

#ifndef _JC_javax_print_attribute_standard_SheetCollate_H_
#define _JC_javax_print_attribute_standard_SheetCollate_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_print_attribute_standard_SheetCollate$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_SheetCollate$sub_refs	_jc_javax_print_attribute_standard_SheetCollate$sub_refs;
typedef struct _jc_javax_print_attribute_standard_SheetCollate$sub_nonrefs	_jc_javax_print_attribute_standard_SheetCollate$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_SheetCollate$refs	_jc_javax_print_attribute_standard_SheetCollate$refs;
typedef struct _jc_javax_print_attribute_standard_SheetCollate$nonrefs	_jc_javax_print_attribute_standard_SheetCollate$nonrefs;
typedef struct _jc_javax_print_attribute_standard_SheetCollate$object	_jc_javax_print_attribute_standard_SheetCollate$object;

typedef struct _jc_javax_print_attribute_standard_SheetCollate$fields_struct	_jc_javax_print_attribute_standard_SheetCollate$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_SheetCollate$vmethods	_jc_javax_print_attribute_standard_SheetCollate$vmethods;
typedef const struct _jc_javax_print_attribute_standard_SheetCollate$vtable	_jc_javax_print_attribute_standard_SheetCollate$vtable;
typedef const struct _jc_javax_print_attribute_standard_SheetCollate$vtype	_jc_javax_print_attribute_standard_SheetCollate$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_SheetCollate$fields_struct {
	struct _jc_javax_print_attribute_standard_SheetCollate$object	*COLLATED;
	struct _jc_javax_print_attribute_standard_SheetCollate$object	*UNCOLLATED;
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24SheetCollate;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_SheetCollate$fields_struct _jc_javax_print_attribute_standard_SheetCollate$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_SheetCollate$method$_init$7f1776288300b98d(_jc_env *, struct _jc_javax_print_attribute_standard_SheetCollate$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_SheetCollate$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_SheetCollate$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_SheetCollate$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_SheetCollate$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_SheetCollate$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_SheetCollate$method_info$getName$bec186f2ce7e1882;

// Static methods
extern void _jc_javax_print_attribute_standard_SheetCollate$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_SheetCollate$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_standard_SheetCollate$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_SheetCollate$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_SheetCollate$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_standard_SheetCollate$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_EnumSyntax$vmethods	javax_print_attribute_EnumSyntax;
	_jc_javax_print_attribute_standard_SheetCollate$vmethods	javax_print_attribute_standard_SheetCollate;
};

// Vtype
struct _jc_javax_print_attribute_standard_SheetCollate$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_SheetCollate$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_SheetCollate$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_SheetCollate$refs {
    _jc_javax_print_attribute_standard_SheetCollate$sub_refs	javax_print_attribute_standard_SheetCollate;
    _jc_javax_print_attribute_EnumSyntax$sub_refs	javax_print_attribute_EnumSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_SheetCollate$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_SheetCollate$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_EnumSyntax$sub_nonrefs	javax_print_attribute_EnumSyntax;
    _jc_javax_print_attribute_standard_SheetCollate$sub_nonrefs	javax_print_attribute_standard_SheetCollate;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_SheetCollate$object {
	_jc_javax_print_attribute_standard_SheetCollate$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_SheetCollate$vtype	*vtype;
	_jc_javax_print_attribute_standard_SheetCollate$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_SheetCollate$vtype _jc_javax_print_attribute_standard_SheetCollate$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_SheetCollate, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_SheetCollate$class_object;

#endif	/* _JC_javax_print_attribute_standard_SheetCollate_H_ */
